@@ -7,7 +7,7 @@
  * Default error handler, set if none is provided by application.
  */
 void _ps_errorhandler(PSDoc *p, int error, const char *str, void *data) {
-	printf("PSLib: %s\n", str);
+	fprintf(stderr, "PSLib: %s\n", str);
 }
 /* }}} */
 
